@@ -1,27 +1,34 @@
 package Search::Elasticsearch::Async;
 
-use Search::Elasticsearch 2.03;
+use Search::Elasticsearch 5.00;
 use Promises 0.93 ();
 use parent 'Search::Elasticsearch';
 
 use Search::Elasticsearch::Util qw(parse_params);
 use namespace::clean;
 
-our $VERSION = '2.03';
+our $VERSION = '5.00';
 
 #===================================
 sub new {
 #===================================
     my ( $class, $params ) = parse_params(@_);
-    $class->SUPER::new(
-        {   cxn_pool            => 'Async::Static',
-            transport           => 'Async',
-            cxn                 => 'AEHTTP',
-            bulk_helper_class   => 'Async::Bulk',
-            scroll_helper_class => 'Async::Scroll',
+    my $self = $class->SUPER::new(
+        {   cxn_pool  => 'Async::Static',
+            transport => 'Async',
+            cxn       => 'AEHTTP',
             %$params
         }
     );
+    unless ( $self->bulk_helper_class ) {
+        $self->bulk_helper_class(
+            'Client::' . $self->api_version . '::Async::Bulk' );
+    }
+    unless ( $self->scroll_helper_class ) {
+        $self->scroll_helper_class(
+            'Client::' . $self->api_version . '::Async::Scroll' );
+    }
+    return $self;
 }
 
 1;
@@ -40,7 +47,7 @@ Search::Elasticsearch::Async - Async API for Elasticsearch using Promises
 
 =head1 VERSION
 
-version 2.03
+version 5.00
 
 =head1 SYNOPSIS
 
@@ -127,15 +134,29 @@ L<Mojolicious> or with any of the event loops supported by L<AnyEvent>.
 L<Search::Elasticsearch::Async> builds on L<Search::Elasticsearch>, which
 you should see for the main documentation.
 
-=head1 BACKWARDS COMPATIBILITY AND ELASTICSEARCH 0.90.x
+=head1 PREVIOUS VERSIONS OF ELASTICSEARCH
 
-This version of the client supports the Elasticsearch 1.0 branch by
-default, which is not backwards compatible with the 0.90 branch.
+This version of the async client supports the Elasticsearch 5.0 branch,
+which is not backwards compatible with earlier branches.
 
-If you need to talk to a version of Elasticsearch before 1.0.0,
-please use L<Search::Elasticsearch::Client::0_90::Direct> as follows:
+If you need to talk to a version of Elasticsearch before 5.0.0, please
+install one of the following packages:
 
-    $es = Search::Elasticsearch::Async->new( client => '0_90::Direct' );
+=over
+
+=item *
+
+L<Search::Elasticsearch::Client::2_0::Async>
+
+=item *
+
+L<Search::Elasticsearch::Client::1_0::Async>
+
+=item *
+
+L<Search::Elasticsearch::Client::0_90::Async>
+
+=back
 
 =head1 USING PROMISES
 
@@ -279,7 +300,7 @@ is repeated until the application is interrupted with C<Ctrl-C>.:
 
 =head1 CREATING A NEW INSTANCE
 
-The L</new()> method returns a new L<client|Search::Elasticsearch::Client::2_0::Direct>
+The L</new()> method returns a new L<client|Search::Elasticsearch::Client::5_0::Direct>
 which can be used to run requests against the Elasticsearch cluster.
 
     use Search::Elasticsearch::Async;
@@ -312,7 +333,7 @@ Each C<node> can be a URL including a scheme, host, port, path and userinfo
 
     https://username:password@search.domain.com:443/prefix/path
 
-See L<Search::Elasticsearch::Role::Cxn::HTTP/node> for more on node specification.
+See L<Search::Elasticsearch::Role::Cxn/node> for more on node specification.
 
 =head2 C<cxn_pool>
 
@@ -399,7 +420,7 @@ Other arguments are explained in the respective L<module docs|/MODULES>.
 =head1 RUNNING REQUESTS
 
 When you create a new instance of Search::Elasticsearch::Async, it returns a
-L<client|Search::Elasticsearch::Client::2_0::Direct> object, which can be used for
+L<client|Search::Elasticsearch::Client::5_0::Direct> object, which can be used for
 running requests.
 
     use Search::Elasticsearch::Async;
@@ -423,7 +444,7 @@ running requests.
         );
     });
 
-See L<Search::Elasticsearch::Client::2_0::Direct> for more details about the requests
+See L<Search::Elasticsearch::Client::5_0::Direct> for more details about the requests
 that can be run.
 
 =head1 MODULES
@@ -455,26 +476,25 @@ methods that can be called to execute requests, such as
 C<search()>, C<index()> or C<delete()>. The client parses the user's
 requests and passes them to the L</transport> class to be executed.
 
-The default version of the client is C<2_0::Direct>, which can
+The default version of the client is C<5_0::Direct>, which can
 be explicitly specified as follows:
 
     $e = Search::Elasticsearch::Async->new(
-        client => '2_0::Direct'
+        client => '5_0::Direct'
     );
 
 See :
 
 =over
 
-=item * L<Search::Elasticsearch::Client::2_0::Direct> (default, for 2.0 branch)
+=item * L<Search::Elasticsearch::Client::5_0::Direct> (default, for 5.0 branch)
+
+=item * L<Search::Elasticsearch::Client::2_0::Direct> (for 2.0 branch)
 
 =item * L<Search::Elasticsearch::Client::1_0::Direct> (for 1.0 branch)
 
 =item * L<Search::Elasticsearch::Client::0_90::Direct> (for 0.90 branch)
 
-=item * L<Search::Elasticsearch::Client::Compat> (for migration from the old
-L<ElasticSearch> module)
-
 =back
 
 =head2 C<transport>
@@ -558,7 +578,7 @@ bodies.  See:
 
 =head1 HELPER MODULES
 
-L<Search::Elasticsearch::Async::Bulk> and L<Search::Elasticsearch::Async::Scroll>
+L<Search::Elasticsearch::Client::5_0::Async::Bulk> and L<Search::Elasticsearch::Client::5_0::Async::Scroll>
 are helper modules which assist with bulk indexing and scrolled searching, eg:
 
     $es->scroll_helper(
@@ -605,7 +625,7 @@ C<irc.freenode.net>.
 
 =item * Mailing list
 
-The main L<Elasticsearch mailing list|http://www.elastic.co/community>.
+The main L<Elasticsearch mailing list|http://discuss.elastic.co>.
 
 =back
 
