@@ -1,13 +1,12 @@
 package Search::Elasticsearch::Cxn::Mojo;
-$Search::Elasticsearch::Cxn::Mojo::VERSION = '2.03';
+$Search::Elasticsearch::Cxn::Mojo::VERSION = '5.00';
 use Mojo::UserAgent();
 use Promises qw(deferred);
 use Try::Tiny;
 use Moo;
 
 with 'Search::Elasticsearch::Role::Cxn::Async';
-with 'Search::Elasticsearch::Role::Cxn::HTTP',
-    'Search::Elasticsearch::Role::Cxn',
+with 'Search::Elasticsearch::Role::Cxn',
     'Search::Elasticsearch::Role::Is_Async';
 
 has 'connect_timeout' => ( is => 'ro', default => 2 );
@@ -26,7 +25,9 @@ sub perform_request {
     my @args = ( $method, $uri, \%headers );
     my $data = $params->{data};
     if ( defined $data ) {
-        $headers{'Content-Type'} = $params->{mime_type};
+        $headers{'Content-Type'}     = $params->{mime_type};
+        $headers{'Content-Encoding'} = $params->{encoding}
+            if $params->{encoding};
         push @args, $data;
     }
 
@@ -105,7 +106,7 @@ Search::Elasticsearch::Cxn::Mojo - An async Cxn implementation which uses Mojo::
 
 =head1 VERSION
 
-version 2.03
+version 5.00
 
 =head1 DESCRIPTION
 
@@ -113,9 +114,9 @@ Provides an async HTTP Cxn class based on L<Mojo::UserAgent>.
 The Mojo backend is fast, uses pure Perl, support proxies and https
 and provides persistent connections.
 
-This class does L<Search::Elasticsearch::Role::Cxn::HTTP>, whose documentation
+This class does L<Search::Elasticsearch::Role::Cxn>, whose documentation
 provides more information, L<Search::Elasticsearch::Role::Async::Cxn>,
-L<Search::Elasticsearch::Role::Cxn> and L<Search::Elasticsearch::Role::Is_Async>.
+and L<Search::Elasticsearch::Role::Is_Async>.
 
 =head1 CONFIGURATION
 
@@ -127,22 +128,18 @@ environment with low network latency.
 
 =head2 Inherited configuration
 
-From L<Search::Elasticsearch::Role::Cxn::HTTP>
-
-=over
-
-=item * L<node|Search::Elasticsearch::Role::Cxn::HTTP/"node">
-
-=item * L<max_content_length|Search::Elasticsearch::Role::Cxn::HTTP/"max_content_length">
-
-=item * L<deflate|Search::Elasticsearch::Role::Cxn::HTTP/"deflate">
-
-=back
-
 From L<Search::Elasticsearch::Role::Cxn>
 
 =over
 
+=item * L<node|Search::Elasticsearch::Role::Cxn/"node">
+
+=item * L<max_content_length|Search::Elasticsearch::Role::Cxn/"max_content_length">
+
+=item * L<deflate|Search::Elasticsearch::Role::Cxn/"gzip">
+
+=item * L<deflate|Search::Elasticsearch::Role::Cxn/"deflate">
+
 =item * L<request_timeout|Search::Elasticsearch::Role::Cxn/"request_timeout">
 
 =item * L<ping_timeout|Search::Elasticsearch::Role::Cxn/"ping_timeout">
@@ -227,38 +224,22 @@ error if the request failed.
 
 =head2 Inherited methods
 
-From L<Search::Elasticsearch::Role::Cxn::HTTP>
-
-=over
-
-=item * L<scheme()|Search::Elasticsearch::Role::Cxn::HTTP/"scheme()">
-
-=item * L<is_https()|Search::Elasticsearch::Role::Cxn::HTTP/"is_https()">
-
-=item * L<userinfo()|Search::Elasticsearch::Role::Cxn::HTTP/"userinfo()">
-
-=item * L<default_headers()|Search::Elasticsearch::Role::Cxn::HTTP/"default_headers()">
-
-=item * L<max_content_length()|Search::Elasticsearch::Role::Cxn::HTTP/"max_content_length()">
-
-=item * L<build_uri()|Search::Elasticsearch::Role::Cxn::HTTP/"build_uri()">
-
-=back
-
-From L<Search::Elasticsearch::Role::Async::Cxn>
-
-=over
-
-=item * L<pings_ok()|Search::Elasticsearch::Role::Cxn/"pings_ok()">
-
-=item * L<sniff()|Search::Elasticsearch::Role::Cxn/"sniff()">
-
-=back
-
 From L<Search::Elasticsearch::Role::Cxn>
 
 =over
 
+=item * L<scheme()|Search::Elasticsearch::Role::Cxn/"scheme()">
+
+=item * L<is_https()|Search::Elasticsearch::Role::Cxn/"is_https()">
+
+=item * L<userinfo()|Search::Elasticsearch::Role::Cxn/"userinfo()">
+
+=item * L<default_headers()|Search::Elasticsearch::Role::Cxn/"default_headers()">
+
+=item * L<max_content_length()|Search::Elasticsearch::Role::Cxn/"max_content_length()">
+
+=item * L<build_uri()|Search::Elasticsearch::Role::Cxn/"build_uri()">
+
 =item * L<host()|Search::Elasticsearch::Role::Cxn/"host()">
 
 =item * L<port()|Search::Elasticsearch::Role::Cxn/"port()">
@@ -287,6 +268,16 @@ From L<Search::Elasticsearch::Role::Cxn>
 
 =back
 
+From L<Search::Elasticsearch::Role::Async::Cxn>
+
+=over
+
+=item * L<pings_ok()|Search::Elasticsearch::Role::Cxn/"pings_ok()">
+
+=item * L<sniff()|Search::Elasticsearch::Role::Cxn/"sniff()">
+
+=back
+
 =head1 SEE ALSO
 
 =over
