@@ -1,5 +1,5 @@
 package Search::Elasticsearch::CxnPool::Async::Sniff;
-$Search::Elasticsearch::CxnPool::Async::Sniff::VERSION = '2.03';
+$Search::Elasticsearch::CxnPool::Async::Sniff::VERSION = '5.00';
 use Moo;
 with 'Search::Elasticsearch::Role::CxnPool::Sniff',
     'Search::Elasticsearch::Role::Is_Async';
@@ -87,15 +87,14 @@ sub sniff {
 
         return if $done;
         my ( $cxn, $nodes ) = @_;
-        if ( $nodes && $self->parse_sniff( $cxn->protocol, $nodes ) ) {
+        if ( $nodes && $self->parse_sniff($nodes) ) {
             $done++;
             $self->_clear_sniff;
             return $deferred->resolve();
         }
 
         unless ( @all || $done_seeds++ ) {
-            $self->logger->infof(
-                "No live nodes available. Trying seed nodes.");
+            $self->logger->info("No live nodes available. Trying seed nodes.");
             @all = $self->_seeds_as_cxns;
         }
 
@@ -142,7 +141,7 @@ Search::Elasticsearch::CxnPool::Async::Sniff - An async CxnPool for connecting t
 
 =head1 VERSION
 
-version 2.03
+version 5.00
 
 =head1 SYNOPSIS
 
@@ -170,7 +169,7 @@ cluster, they will be auto-discovered during a sniff.
 If all sniffed nodes fail, then it falls back to sniffing the original
 I<seed> nodes that you specified in C<new()>.
 
-For L<HTTP Cxn classes|Search::Elasticsearch::Role::Cxn::HTTP>, this module
+For L<HTTP Cxn classes|Search::Elasticsearch::Role::Cxn>, this module
 will also dynamically detect the C<max_content_length> which the nodes
 in the cluster will accept.
 
@@ -183,7 +182,7 @@ L<Search::Elasticsearch::Role::Is_Async>.
 
 The list of nodes to use to discover the cluster.  Can accept a single node,
 multiple nodes, and defaults to C<localhost:9200> if no C<nodes> are
-specified. See L<Search::Elasticsearch::Role::Cxn::HTTP/node> for details of the node
+specified. See L<Search::Elasticsearch::Role::Cxn/node> for details of the node
 specification.
 
 =head2 C<concurrent_sniff>
