@@ -1,5 +1,5 @@
 package Search::Elasticsearch::CxnPool::Async::Static;
-$Search::Elasticsearch::CxnPool::Async::Static::VERSION = '2.03';
+$Search::Elasticsearch::CxnPool::Async::Static::VERSION = '5.00';
 use Moo;
 with 'Search::Elasticsearch::Role::CxnPool::Static',
     'Search::Elasticsearch::Role::Is_Async';
@@ -54,8 +54,7 @@ sub next_cxn {
 
         return $deferred->reject(
             new_error(
-                "NoNodes",
-                "No nodes are available: [" . $self->cxns_str . ']'
+                "NoNodes", "No nodes are available: [" . $self->cxns_str . ']'
             )
         );
 
@@ -82,7 +81,7 @@ Search::Elasticsearch::CxnPool::Async::Static - An async CxnPool for connecting
 
 =head1 VERSION
 
-version 2.03
+version 5.00
 
 =head1 SYNOPSIS
 
@@ -115,7 +114,7 @@ L<Search::Elasticsearch::Role::Is_Async>.
 
 The list of nodes to use to serve requests.  Can accept a single node,
 multiple nodes, and defaults to C<localhost:9200> if no C<nodes> are
-specified. See L<Search::Elasticsearch::Role::Cxn::HTTP/node> for details of the node
+specified. See L<Search::Elasticsearch::Role::Cxn/node> for details of the node
 specification.
 
 =head2 See also
